@@ -8,13 +8,13 @@
 #endif /* HAVE_FULL_QUEUE_H */
 
 struct choice {
-    char *str;
-    char *desc;
-    float score;
-    SLIST_ENTRY(choice) choices;          /* List. */
+	char *string;
+	char *description;
+	float score;
+	SLIST_ENTRY(choice) choices;
 };
 
-struct choice   *choice_new(char *, char *, float);
-void             choice_free(struct choice *);
+struct choice	*choice_new(char *, char *, float);
+void		 choice_free(struct choice *);
 
 #endif /* CHOICHE_H */
